/* used to help manage pictures for displaying */

parse arg source template . '(' hole number last_number
if source = '?' | source = '/?' | source = '' then do
   say "Four calling methods:"
   say "1st is:"
   say "  'copypics g:\subdir\*.jpg pic*.jpg'"
   say "     This will copy all *.jpg files into the current directory naming them"
   say "     sequentially using the pic*.jpg as a template"
   say "2nd is similar to 1st, but the file names are ordered in a list.  This"
   say "     is signaled by an '=' as the first character of the source spec."
   say "3rd is:"
   say "  'copypics g:\subdir\*.jpg pic*.jpg ( first_number_to_use'"
   say "     Same as 1st case but the number starts as specified."
   say "4th is:"
   say "  'copypics ( hole_to_create  number_of_empty_numbers  last_existing_number'"
   say "     This is used to make a hole such that more pictures can be logically"
   say "     inserted in the sequence"

   exit 100
end

source_name_spec = filespec('name',source)
if source_name_spec \= '' then do
   if (left(source,1) \= '=') then do
      dot_pos = lastpos('.',source_name_spec)
      if dot_pos = 0 then do
         source = source || '.jpg'
      end
   end
end
else source = source || '*.jpg'

if left(source,1) = '"' then
   parse arg '"' source '"' template .
if template = '' then template = 'pic*.jpg'

call RxFuncAdd "SysLoadFuncs", RexxUtil, "SysLoadFuncs"
call SysLoadFuncs

/* we will substitute numbers at the * in the template */
next_num = 0
parse var template p1 '*' p2

if number = '' then do
   if datatype(hole) = 'NUM'
      then next_num = hole - 1
   if (left(source,1) = '=') then do
      list = substr(source,2)
      i = 0
      Do until substr(stream(list,"D"),1,8) = 'NOTREADY'
         data_line = linein(list)
         if left(data_line,1) = '*' then iterate
         if left(data_line,1) = '"' then do
            parse var data_line '"' data_line '"'
         end
         else if words(data_line) \= 1 then iterate
         i = i + 1
         candidates.i = '. . . .' data_line
      end
      candidates.0 = i
      rc = stream(list,'c','close')
   end

   else do
      rc = SysFileTree(source,candidates,"F")
      seqn.0 = ''
      do i = 1 to candidates.0
         parse var candidates.i . . . . fn      /* if name follows our naming  */
         nfn = filespec('name',fn)              /*    convention, parse 'n'    */
         if translate(left(nfn,3)) = 'PIC' | translate(left(nfn,5)) = 'MOVIE' then do

            /* new order will be based on numerical pattern */
            if translate(left(nfn,3)) = 'PIC'
               then parse value translate(nfn) with . 'PIC' n '.' ext
               else parse value translate(nfn) with . 'MOVIE' n '.' ext
            seqn.i = 10000 + n  candidates.i
            if seqn.0 = ''
               then seqn.0 = 'numeric_order'
         end
         else seqn.0 = 'no pattern'
      end

      /* if all files followed our special naming convention */
      if seqn.0 = 'numeric_order' then do
         /* bubble sort them into numerical order */
         do i = 1 to candidates.0 - 1
            do n = i + 1 to candidates.0
               if word(seqn.n,1) < word(seqn.i,1) then do
                  nfn = candidates.i
                  candidates.i = candidates.n
                  candidates.n = nfn

                  nfn = seqn.i
                  seqn.i = seqn.n
                  seqn.n = nfn
               end
            end
         end
      end
   end

   do i = 1 to candidates.0
      parse var candidates.i . . . . fn

      do until rc = ''
         next_num = next_num + 1
         nfn = p1||next_num||p2
         rc = stream(nfn,'c','query exists')
      end

      'copy "'||strip(fn)||'"' nfn
   end
end
else do
   if last_number = '' then last_number = 9999
   do until rc \= ''
      nfn = p1||last_number||p2
      rc = stream(nfn,'c','query exists')
      if rc = ''
         then last_number = last_number - 1
   end

   say 'last existing file is' nfn

   do i = last_number to hole by -1
      fn = p1||i||p2
      nfn = p1||i+number||p2
      'rename' fn nfn
      if rc \= 0 then leave
   end
end
